pub enum JoinAlgorithm {
Hash,
NestedLoop,
Merge,
}Expand description
Which join algorithm to use for a given join node
Variants
Hash
Hash join: good when one side is small enough to fit in memory
NestedLoop
Nested loop join: good when outer is tiny and inner has index support
Merge
Sort-merge join: good for large sorted inputs with shared sort keys