pub enum PatternTerm {
Variable(String),
Iri(String),
Literal(String),
BlankNode(String),
}Expand description
A term in a triple pattern (subject, predicate, or object position)
Variants
Implementations
Sourceimpl PatternTerm
impl PatternTerm
Sourcepub fn is_variable(&self) -> bool
pub fn is_variable(&self) -> bool
Return true if this term is a variable (unbound position)
Sourcepub fn variable_name(&self) -> Option<&str>
pub fn variable_name(&self) -> Option<&str>
Return the variable name if this is a variable