pub enum PatternTerm {
Iri(String),
Literal(String),
Variable(String),
BlankNode(String),
}Expand description
A position in a triple pattern – can be an IRI, a plain literal, a blank node, or a variable (placeholder for pattern matching).
Variants
Implementations
Sourceimpl PatternTerm
impl PatternTerm
Sourcepub fn is_variable(&self) -> bool
pub fn is_variable(&self) -> bool
Returns true when this term is a variable (used during template instantiation).
Sourcepub fn variable_name(&self) -> Option<&str>
pub fn variable_name(&self) -> Option<&str>
Returns the variable name if this is a Variable variant.