pub struct QueryExplainer { /* private fields */ }Expand description
Renders a QueryPlan in the requested ExplainFormat.
use oxirs_arq::explain::{QueryExplainer, ExplainFormat, QueryPlan, PlanNode, IndexType};
let plan = QueryPlan {
root: PlanNode::TripleScan {
pattern: "?s ?p ?o".into(),
index_used: IndexType::FullScan,
estimated_rows: 100_000,
},
estimated_cost: 12.5,
estimated_cardinality: 100_000,
};
let exp = QueryExplainer::builder().show_estimates(true).build();
let out = exp.explain_with_format(&plan, ExplainFormat::Json);
assert!(out.contains("\"type\""));Implementations
Sourceimpl QueryExplainer
impl QueryExplainer
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new explainer with default settings (text format, all annotations shown).
Sourcepub fn builder() -> QueryExplainerBuilder
pub fn builder() -> QueryExplainerBuilder
Return a builder for fine-grained configuration.
Sourcepub fn explain(&self, plan: &QueryPlan) -> String
pub fn explain(&self, plan: &QueryPlan) -> String
Render the plan using the format configured at construction time.
Sourcepub fn explain_with_format(
&self,
plan: &QueryPlan,
format: ExplainFormat,
) -> String
pub fn explain_with_format( &self, plan: &QueryPlan, format: ExplainFormat, ) -> String
Render the plan in a specific format, overriding the configured default.
Sourcepub fn explain_text(&self, plan: &QueryPlan) -> String
pub fn explain_text(&self, plan: &QueryPlan) -> String
Render as an indented text tree.
Sourcepub fn explain_json(&self, plan: &QueryPlan) -> String
pub fn explain_json(&self, plan: &QueryPlan) -> String
Render as a JSON object.
Sourcepub fn explain_dot(&self, plan: &QueryPlan) -> String
pub fn explain_dot(&self, plan: &QueryPlan) -> String
Render as Graphviz DOT language.