pub struct QueryExplainerBuilder { /* private fields */ }Expand description
Builder for QueryExplainer.
Implementations
Sourceimpl QueryExplainerBuilder
impl QueryExplainerBuilder
Sourcepub fn show_estimates(self, val: bool) -> Self
pub fn show_estimates(self, val: bool) -> Self
Whether to include estimated row counts in the output.
Sourcepub fn show_costs(self, val: bool) -> Self
pub fn show_costs(self, val: bool) -> Self
Whether to include estimated cost values in the output.
Sourcepub fn format(self, fmt: ExplainFormat) -> Self
pub fn format(self, fmt: ExplainFormat) -> Self
Set the default output format.
Sourcepub fn build(self) -> QueryExplainer
pub fn build(self) -> QueryExplainer
Build the QueryExplainer.