StrBeforeFunction

Struct StrBeforeFunction 

pub struct StrBeforeFunction;
STRBEFORE(str, separator) - Returns the substring before the first occurrence of separator

Returns the part of the string before the first occurrence of the separator. If separator is not found, returns empty string “”. If separator is empty string, returns empty string “”.

Examples

STRBEFORE("abc@example.org", "@") → "abc"
STRBEFORE("foobar", "bar") → "foo"
STRBEFORE("foobar", "xyz") → ""