pub struct StrBeforeFunction;Expand description
STRBEFORE(str, separator) - Returns the substring before the first occurrence of separator
Returns the part of the string before the first occurrence of the separator. If separator is not found, returns empty string “”. If separator is empty string, returns empty string “”.
Examples
STRBEFORE("abc@example.org", "@") → "abc"
STRBEFORE("foobar", "bar") → "foo"
STRBEFORE("foobar", "xyz") → ""Trait Implementations
Sourceimpl Clone for StrBeforeFunction
impl Clone for StrBeforeFunction
Sourcefn clone(&self) -> StrBeforeFunction
fn clone(&self) -> StrBeforeFunction
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CustomFunction for StrBeforeFunction
impl CustomFunction for StrBeforeFunction
Sourcefn parameter_types(&self) -> Vec<ValueType>
fn parameter_types(&self) -> Vec<ValueType>
Function parameter types
Sourcefn return_type(&self) -> ValueType
fn return_type(&self) -> ValueType
Function return type
Sourcefn documentation(&self) -> &str
fn documentation(&self) -> &str
Function documentation
Sourcefn clone_function(&self) -> Box<dyn CustomFunction>
fn clone_function(&self) -> Box<dyn CustomFunction>
Clone this function (for registry operations)
Sourcefn execute(&self, args: &[Value], _context: &ExecutionContext) -> Result<Value>
fn execute(&self, args: &[Value], _context: &ExecutionContext) -> Result<Value>
Execute the function
Sourcefn cost_estimate(&self, args: &[Expression]) -> f64
fn cost_estimate(&self, args: &[Expression]) -> f64
Estimate execution cost
Sourcefn is_deterministic(&self) -> bool
fn is_deterministic(&self) -> bool
Check if function is deterministic
Sourcefn can_pushdown(&self) -> bool
fn can_pushdown(&self) -> bool
Check if function can be pushed down